summaryrefslogtreecommitdiffstats
path: root/android_webview/common
diff options
context:
space:
mode:
authormkosiba@chromium.org <mkosiba@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-18 07:33:51 +0000
committermkosiba@chromium.org <mkosiba@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-18 07:33:51 +0000
commit9121970a1c6c5b44d036db5553acc7001453813a (patch)
tree04bc044ce3c486c4236163ed0c5532a840233fc9 /android_webview/common
parente5a631a54357c85ae8380e9d82a64173e3440a57 (diff)
downloadchromium_src-9121970a1c6c5b44d036db5553acc7001453813a.zip
chromium_src-9121970a1c6c5b44d036db5553acc7001453813a.tar.gz
chromium_src-9121970a1c6c5b44d036db5553acc7001453813a.tar.bz2
Use new WebView zoom API.
This is a followup to http://crrev.com/23147003 which updates the callsites to use the newly exposed zoom APIs. BUG=275749 Review URL: https://chromiumcodereview.appspot.com/23152004 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@223807 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'android_webview/common')
-rw-r--r--android_webview/common/render_view_messages.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/android_webview/common/render_view_messages.h b/android_webview/common/render_view_messages.h
index b53bcfa..47d06a2 100644
--- a/android_webview/common/render_view_messages.h
+++ b/android_webview/common/render_view_messages.h
@@ -52,10 +52,10 @@ IPC_MESSAGE_ROUTED2(AwViewMsg_DoHitTest,
int /* view_x */,
int /* view_y */)
// Sets the zoom level for text only. Used in layout modes other than
// Text Autosizing.
-IPC_MESSAGE_ROUTED1(AwViewMsg_SetTextZoomLevel,
- double /* zoom_level */)
+IPC_MESSAGE_ROUTED1(AwViewMsg_SetTextZoomFactor,
+ float /* zoom_factor */)
// Resets WebKit WebView scrolling and scale state. We need to send this
// message whenever we want to guarantee that page's scale will be
@@ -52,10 +52,10 @@ IPC_MESSAGE_ROUTED2(AwViewMsg_DoHitTest,
int /* view_x */,
int /* view_y */)
-// Sets the zoom level for text only. Used in layout modes other than
+// Sets the zoom factor for text only. Used in layout modes other than
// Text Autosizing.